@@ -2,7 +2,7 @@ package main
 
 import (
 	"context"
-	_ "embed"
+	"database/sql"
 	"errors"
 	"flag"
 	"fmt"
@@ -110,6 +110,17 @@ func main() {
 			log.Fatalf("goose validate: %v", err)
 		}
 		return
+	case "beta":
+		remain := args[1:]
+		if len(remain) == 0 {
+			log.Println("goose beta: missing subcommand")
+			os.Exit(1)
+		}
+		switch remain[0] {
+		case "drivers":
+			printDrivers()
+		}
+		return
 	}
 
 	args = mergeArgs(args)
@@ -169,6 +180,42 @@ func main() {
 	}
 }
 
+func printDrivers() {
+	drivers := mergeDrivers(sql.Drivers())
+	if len(drivers) == 0 {
+		fmt.Println("No drivers found")
+		return
+	}
+	fmt.Println("Available drivers:")
+	for _, driver := range drivers {
+		fmt.Printf("  %s\n", driver)
+	}
+}
+
+// mergeDrivers merges drivers with a common prefix into a single line.
+func mergeDrivers(drivers []string) []string {
+	driverMap := make(map[string][]string)
+
+	for _, driver := range drivers {
+		parts := strings.Split(driver, "/")
+		if len(parts) > 1 {
+			// Merge drivers with a common prefix "/"
+			prefix := parts[0]
+			driverMap[prefix] = append(driverMap[prefix], driver)
+		} else {
+			// Add drivers without a prefix directly
+			driverMap[driver] = append(driverMap[driver], driver)
+		}
+	}
+	var merged []string
+	for _, versions := range driverMap {
+		sort.Strings(versions)
+		merged = append(merged, strings.Join(versions, ", "))
+	}
+	sort.Strings(merged)
+	return merged
+}
+
 func checkNoColorFromEnv() bool {
 	ok, _ := strconv.ParseBool(cfg.GOOSENOCOLOR)
 	return ok
@@ -214,6 +261,7 @@ Drivers:
     clickhouse
     vertica
     ydb
+    turso
 
 Examples:
     goose sqlite3 ./foo.db status
@@ -230,12 +278,14 @@ Examples:
     goose clickhouse "tcp://127.0.0.1:9000" status
     goose vertica "vertica://user:password@localhost:5433/dbname?connection_load_balance=1" status
     goose ydb "grpcs://localhost:2135/local?go_query_mode=scripting&go_fake_tx=scripting&go_query_bind=declare,numeric" status
+	goose turso "libsql://dbname.turso.io?authToken=token" status
 
     GOOSE_DRIVER=sqlite3 GOOSE_DBSTRING=./foo.db goose status
     GOOSE_DRIVER=sqlite3 GOOSE_DBSTRING=./foo.db goose create init sql
     GOOSE_DRIVER=postgres GOOSE_DBSTRING="user=postgres dbname=postgres sslmode=disable" goose status
     GOOSE_DRIVER=mysql GOOSE_DBSTRING="user:password@/dbname" goose status
     GOOSE_DRIVER=redshift GOOSE_DBSTRING="postgres://user:password@qwerty.us-east-1.redshift.amazonaws.com:5439/db" goose status
+    GOOSE_DRIVER=turso GOOSE_DBSTRING="libsql://dbname.turso.io?authToken=token" goose status
 
 Options:
 `
