@@ -17,10 +17,12 @@ func OpenDBWithDriver(driver string, dbstring string) (*sql.DB, error) {
 		driver = "sqlserver"
 	case "tidb":
 		driver = "mysql"
+	case "turso":
+		driver = "libsql"
 	}
 
 	switch driver {
-	case "postgres", "pgx", "sqlite3", "sqlite", "mysql", "sqlserver", "clickhouse", "vertica", "azuresql", "ydb":
+	case "postgres", "pgx", "sqlite3", "sqlite", "mysql", "sqlserver", "clickhouse", "vertica", "azuresql", "ydb", "libsql":
 		return sql.Open(driver, dbstring)
 	default:
 		return nil, fmt.Errorf("unsupported driver %s", driver)
